@import url("torillic/torillic.css");
@import url("ipa.css");
@import url("statblock.css");


body {
    padding: 0;
    margin: 0;
}

blockquote.torillic-toc {
    display: flex;
    flex-direction: column;
    break-inside: avoid;
}

li.torillic-toc-section {
    order: 1;
}
li.torillic-toc-section::marker {
    content: ">";
    font-weight: bold;
}

li.torillic-toc-page {
    order: 2
}
li.torillic-toc-page::marker {
    content: "-";
    font-weight: bold;
}

.torillic-background {
    padding: 4rem;
}

.torillic-backlink {
    position: absolute;
    top: 1cm;
    left: 2cm;
    text-decoration: none;
    opacity: 20%;
}
.torillic-backlink:hover {
    color: var(--red);
    opacity: 100%;
}


@media print {
    .torillic-backlink {
        display: none;
    }
    .torillic-header {
        display: none;
    }
}